@@ -255,7 +255,7 @@ class RestAPI(object):
 					subscriptions[email]["plans"][id]["plan_active_status"] = active
 
 			# success.
-			#print(json.dumps(subscriptions, indent=4))
+			print(json.dumps(subscriptions, indent=4))
 			return r3sponse.success_response("Successfully retrieved the subscriptions.", {
 				"subscriptions":subscriptions,
 			})
